==> massxpert2_8.3.0.orig.tar.gz: massxpert2-8.3.0/src/nongui/PkaPhPiDataParser.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef PKA_PH_PI_DATA_PARSER_HPP
#define PKA_PH_PI_DATA_PARSER_HPP


/////////////////////// Local includes
#include "libmass/PolChemDef.hpp"
#include <libmass/PolChemDefEntity.hpp>


namespace msxps
{

	namespace massxpert
	{



class PkaPhPiDataParser
{
  private:
  libmass::PolChemDefCstSPtr mcsp_polChemDef;
  QString m_filePath;

  public:
  PkaPhPiDataParser(const libmass::PolChemDefCstSPtr, QString = QString());

  ~PkaPhPiDataParser();

  void setFilePath(const QString &);
  const QString &filePath();

  bool renderXmlFile(QList<libmass::Monomer *> *, QList<libmass::Modif *> *);
};

} // namespace massxpert

} // namespace msxps


#endif // PKA_PH_PI_DATA_PARSER_HPP

==> massxpert_6.0.2.orig.tar.gz: massxpert-6.0.2/src/nongui/PkaPhPiDataParser.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef PKA_PH_PI_DATA_PARSER_HPP
#define PKA_PH_PI_DATA_PARSER_HPP


/////////////////////// Local includes
#include "PolChemDef.hpp"


namespace msxps
{

	namespace massxpert
	{



class PkaPhPiDataParser
{
  private:
  const PolChemDef *mp_polChemDef;
  QString m_filePath;

  public:
  PkaPhPiDataParser(const PolChemDef *, QString = QString());

  ~PkaPhPiDataParser();

  void setFilePath(const QString &);
  const QString &filePath();

  bool renderXmlFile(QList<Monomer *> *, QList<Modif *> *);
};

} // namespace massxpert

} // namespace msxps


#endif // PKA_PH_PI_DATA_PARSER_HPP
